@@ -4,14 +4,13 @@
 # This requires Git and git-lfs to be installed.
 #
 # Copyright (C) 2019—2021 Collabora Ltd
-# Andrej Shadura <andrew.shadura@collabora.co.uk>
+# Copyright (C) 2019—2021 Andrej Shadura <andrew.shadura@collabora.co.uk>
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 from __future__ import annotations
 
 import hashlib
-import logging
 import os
 from contextlib import contextmanager
 from fnmatch import fnmatch, fnmatchcase
@@ -22,7 +21,14 @@ from typing import IO, Any, Generator, Iterable, Mapping, Optional, Sequence, Tu
 import sh
 from debian.changelog import Version
 
+from .errors import (
+    DifferentFilesExist,
+    GitBranchNotFound,
+    GitFileNotFound,
+    UnsupportedHashAlgorithm,
+)
 from .gitwrap import git
+from .log import logger
 
 
 gitattributes = """*.tar.* filter=lfs diff=lfs merge=lfs -text
@@ -133,22 +139,6 @@ def parse_git_attributes(s: str) -> Iterable[tuple[str, Mapping[str, AttributeVa
 default_gitattributes = list(parse_git_attributes(gitattributes))
 
 
-class Abort(Exception):
-    pass
-
-
-class GitFileNotFound(Exception):
-    filename: str
-    branch: str
-
-    def __init__(self, filename: str, branch: str):
-        self.filename = filename
-        self.branch = branch
-
-    def __str__(self):
-        return _('%s not found on branch %s') % (self.filename, self.branch)
-
-
 def check_branch(name: str) -> Optional[str]:
     """
     Check a branch exists, return the hash it points at, if it does.
@@ -187,9 +177,9 @@ def find_remote_branches(name: str) -> list[tuple[str, str]]:
 
 
 def preferred_remote_branch(remote_branches: list[tuple[str, str]]) -> tuple[str, str]:
-    logging.debug("Remote branches: %r", remote_branches)
+    logger.debug("Remote branches: %r", remote_branches)
     current_remote = branch_remote(git_head())
-    logging.debug("Current remote: %r", current_remote)
+    logger.debug("Current remote: %r", current_remote)
     remote_branches = [
         (commit, ref) for (commit, ref) in remote_branches
         if current_remote and ref.startswith('refs/remotes/' + current_remote)
@@ -211,7 +201,7 @@ def find_branch(branch: str) -> str:
         if remote_branches:
             commit, branch = preferred_remote_branch(remote_branches)
         else:
-            raise Abort(_('No branch {branch} found, not even among remote branches').format(branch=branch))
+            raise GitBranchNotFound(branch)
     return branch
 
 
@@ -307,7 +297,7 @@ def commit_lfs_files(ios: Sequence[IO[bytes]], branch: str, template: str = None
             hook_path.write_text(pre_push_hook)
             hook_path.chmod(0o755)
         except IOError as e:
-            logging.warning(_('Failed to set up pre-push hook: %s') % e.strerror)
+            logger.warning(_('Failed to set up pre-push hook: %s') % e.strerror)
 
     with open_index("pristine-lfs") as index:
         # make sure we include all previously committed files
@@ -328,12 +318,12 @@ def commit_lfs_files(ios: Sequence[IO[bytes]], branch: str, template: str = None
         if check_branch(branch) is not None:
             diff = git('diff-index', '--cached', branch, index=index).strip().splitlines()
             if not diff:
-                logging.info(_("Nothing to commit"))
+                logger.info(_("Nothing to commit"))
                 return
             parsed_diff = [parse_diff_entry(d) for d in diff]
             overwritten = [d['srcname'] for d in parsed_diff if d['srchash'] != ('0' * 40) and d['srcname'] != '.gitattributes']
             if any(overwritten) and not overwrite:
-                raise Abort(_('would overwrite files: %s') % ', '.join(overwritten))
+                raise DifferentFilesExist(overwritten)
 
         if not template:
             template = "pristine-lfs data for %s"
@@ -399,7 +389,7 @@ def verify_lfs_file(branch: str, tarball: Path) -> bool:
     oid = parsed_metadata['oid']
     algo, hashsum = oid.split(':', 1)
     if algo not in supported_lfs_hashsums:
-        raise Abort(_("unsupported hash algorithm %s, cannot verify") % algo)
+        raise UnsupportedHashAlgorithm(algo)
 
     h = getattr(hashlib, algo)()
     with open(tarball, mode='rb') as f:
@@ -410,9 +400,9 @@ def verify_lfs_file(branch: str, tarball: Path) -> bool:
             h.update(chunk)
     calc_hashsum = h.hexdigest()
     if hashsum == calc_hashsum:
-        logging.info(f"{algo} hash for the tarball: {hashsum}, matches the stored one")
+        logger.info(f"{algo} hash for the tarball: {hashsum}, matches the stored one")
     else:
-        logging.warning(_("%(tarball)s does not match stored hash (expected %(stored_hash)s, got %(tarball_hash)s)") % {
+        logger.warning(_("%(tarball)s does not match stored hash (expected %(stored_hash)s, got %(tarball_hash)s)") % {
             'tarball': filename,
             'stored_hash': hashsum,
             'tarball_hash': calc_hashsum,
@@ -420,8 +410,12 @@ def verify_lfs_file(branch: str, tarball: Path) -> bool:
     return hashsum == calc_hashsum
 
 
-def checkout_package(package: str, version: Version, branch: str, outdir: Union[str, Path], requested: Optional[Sequence[str]] = None):
-    logging.info(_("Checking out files for {package} version {version} to {outdir}:").format(package=package, version=version, outdir=outdir))
+def checkout_package(package: str, version: Version, branch: str, outdir: Union[str, Path],
+                     requested: Optional[Sequence[str]] = None):
+    logger.info(_("Checking out files for {package} version {version} to {outdir}:").format(
+        package=package,
+        version=version, outdir=outdir
+    ))
     tarball_glob = f'{package}_{version.upstream_version}.orig.tar.*'
     component_tarball_glob = f'{package}_{version.upstream_version}.orig-*.tar.*'
 
@@ -433,9 +427,9 @@ def checkout_package(package: str, version: Version, branch: str, outdir: Union[
         tarballs = [f for f in files if fnmatch(f, tarball_glob) or fnmatch(f, component_tarball_glob)]
 
     for f in tarballs:
-        logging.info("         ... {}".format(f))
+        logger.info("         ... {}".format(f))
         checkout_lfs_file(branch, f, outdir)
-    logging.info(_("Done."))
+    logger.info(_("Done."))
 
 
 def parse_pointer(pointer: IO[str]) -> Iterable[tuple[str, str]]:
