@@ -1,8 +1,10 @@
 from textwrap import dedent
 
+import pytest
 from sh.contrib import git
 
 from pristine_lfs import do_commit
+from pristine_lfs.errors import DifferentFilesExist
 
 
 def test_pristine_lfs_commit(fake_tarball):
@@ -24,3 +26,13 @@ def test_pristine_lfs_commit(fake_tarball):
 
     stored = repo / '.git' / 'lfs' / 'objects' / sha[:2] / sha[2:4] / sha
     assert stored.is_file(), 'Object has not been stored by LFS'
+
+
+def test_pristine_lfs_commit_overwrite(fake_tarball):
+    repo, tarball, size, sha = fake_tarball
+
+    do_commit(tarball.open('rb'), branch='pristine-lfs')
+    tarball.write_text('Text')
+
+    with pytest.raises(DifferentFilesExist):
+        do_commit(tarball.open('rb'), branch='pristine-lfs', message='blip %s %s %s')
